==> iwrite-1.0.1.4.tar.gz: iwrite-1.0.1.4/src/item_page_number.h <==
/* 
vim:expandtab:softtabstop=2:tabstop=2:shiftwidth=2:nowrap:ruler
*/
/*
Copyright (c) 2015-2016, iwrite authors
All rights reserved.

Redistribution and use in source and binary forms, with or without
modification, are permitted provided that the following conditions
are met:

1. Redistributions of source code must retain the above copyright notice,
this list of conditions and the following disclaimer.

2. Redistributions in binary form must reproduce the above copyright
notice, this list of conditions and the following disclaimer in the
documentation and/or other materials provided with the distribution.

THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS
"AS IS" AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT
LIMITED TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR
A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT
HOLDER OR CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL,
SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED
TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR
PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF
LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING
NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF THIS
SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
*/
#ifndef __item_page_number_h__

#include "item_common.h"
#include "item_method.h"

enum page_number_type
{
  page_number_all= 0,
  page_number_even,
  page_number_odd 
};

struct item_page_number
{
  double                                m_pos_x;
  double                                m_pos_y;
  double                                m_len_x;
  double                                m_len_y;
  PangoFontDescription*                 m_font; 
  GdkRGBA                               m_color;
  int                                   m_border;
  enum line_style_type                  m_border_style;
  double                                m_border_thickness;
  GdkRGBA                               m_border_color;
  int                                   m_fill;
  GdkRGBA                               m_fill_color;
  unsigned long                         m_page_number;
  enum page_number_type                 m_type;
  char                                  m_format[1+FIELD_FORMAT_MAX_LEN];
};

extern void
item_page_number_assign(
  struct item_page_number*const         o_page_number,
  struct item_method*const              o_method);

extern void
item_page_number_extent_update(
  struct item_page_number*const         io_page_number);

extern void
item_page_number_discharge(
  struct item_page_number*const         io_page_number);

extern void
item_page_number_get_bbox(
  struct geom_rect*const                o_bbox,
  int*const                             o_overlay,
  void const*const                      i_object);

extern void
item_page_number_in_event(
  enum event_type*const                 o_type,
  struct item_page_number const*const   i_page_number,
  struct item_in_event const*const      i_ctx);

extern void
item_page_number_draw(
  struct item_page_number*const         io_page_number,
  struct item_draw_context const*const  i_ctx);

extern void
item_page_number_move(
  struct item_page_number*const         io_page_number,
  struct geom_point const*const         i_event);

extern void
item_page_number_normalize(
  struct item_page_number*const         io_page_number,
  double const                          i_bound_width,
  double const                          i_bound_height);

extern int
item_page_number_property(
  struct item_page_number*const         io_page_number);

extern int
item_page_number_read(
  GError**                              o_error,
  struct item_page_number*const         io_page_number,
  struct bson_node *const               i_element);

extern void
item_page_number_resize(
  struct item_page_number*const         io_page_number,
  struct item_resize_event const*const  i_ctx);

extern int
item_page_number_write(
  GError**                              o_error,
  FILE*const                            io_fp,
  struct item_page_number const*const   io_page_number);

#define __item_page_number_h__
#endif

==> iwrite-2.0.1.0.tar.gz: iwrite-2.0.1.0/src/item_page_number.h <==
/* 
vim:expandtab:softtabstop=2:tabstop=2:shiftwidth=2:nowrap:ruler
*/
/*
Copyright (c) 2015-2016, iwrite authors
All rights reserved.

Redistribution and use in source and binary forms, with or without
modification, are permitted provided that the following conditions
are met:

1. Redistributions of source code must retain the above copyright notice,
this list of conditions and the following disclaimer.

2. Redistributions in binary form must reproduce the above copyright
notice, this list of conditions and the following disclaimer in the
documentation and/or other materials provided with the distribution.

THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS
"AS IS" AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT
LIMITED TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR
A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT
HOLDER OR CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL,
SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED
TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR
PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF
LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING
NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF THIS
SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
*/
#ifndef __item_page_number_h__

#include "item_common.h"
#include "item_method.h"

enum page_number_type
{
  page_number_all= 0,
  page_number_even,
  page_number_odd 
};

struct item_page_number
{
  gdouble                               m_pos_x;
  gdouble                               m_pos_y;
  gdouble                               m_len_x;
  gdouble                               m_len_y;
  PangoFontDescription*                 m_font; 
  GdkRGBA                               m_color;
  struct item_border_attr               m_border;
  struct item_fill                      m_fill;
  enum page_number_type                 m_type;
  gchar                                 m_format[1+FIELD_FORMAT_MAX_LEN];
  guint64                               m_page_number;
};

extern void
item_page_number_assign(
  struct item_page_number*const         o_page_number,
  struct item_method*const              o_method);

extern void
item_page_number_extent_update(
  struct item_page_number*const         io_page_number);

extern void
item_page_number_discharge(
  struct item_page_number*const         io_page_number);

extern void
item_page_number_get_bbox(
  struct geom_rect*const                o_bbox,
  void const*const                      i_object);

extern void
item_page_number_in_event(
  enum event_type*const                 o_type,
  struct item_page_number const*const   i_page_number,
  struct item_in_event const*const      i_ctx);

extern void
item_page_number_draw(
  struct item_page_number*const         io_page_number,
  struct item_draw_context const*const  i_ctx);

extern void
item_page_number_move(
  struct item_page_number*const         io_page_number,
  struct geom_point const*const         i_event);

extern void
item_page_number_normalize(
  struct item_page_number*const         io_page_number,
  double const                          i_bound_width,
  double const                          i_bound_height);

extern int
item_page_number_property(
  struct item_page_number*const         io_page_number);

extern int
item_page_number_read(
  GError**                              o_error,
  struct item_page_number*const         io_page_number,
  struct xml *const               i_element);

extern void
item_page_number_resize(
  struct item_page_number*const         io_page_number,
  struct item_resize_event const*const  i_ctx);

extern int
item_page_number_write(
  GError**                              o_error,
  FILE*const                            io_fp,
  struct item_page_number const*const   io_page_number);

#define __item_page_number_h__
#endif
